@@ -13,34 +13,26 @@
 #include <set>
 
 
-
 class CountTableAdapter {
 public:
     CountTableAdapter() = default;
-    bool CreateDataFrameMap(const Rcpp::DataFrame& countTable);
+    bool CreateDataFrameMap(const Rcpp::DataFrame& count);
     bool CreateDataFrameMapFromSparseCountTable(const Rcpp::DataFrame& countTable);
-    std::vector<std::string> GetSamples() const {return sampleNames;}
+    std::vector<std::string> GetSequences() const {return sequenceNames;}
     // Going to ensure that each count_table atleast has a group
     // And if there is no count table inputted, I will create a base one.
     double FindAbundanceBasedOnGroup(const std::string& group, const std::string& sampleName) const;
     double FindTotalAbundance(const std::string& sampleName) const;
-    std::string GetNameByIndex(int) const;
+    std::string GetNameByIndex(size_t) const;
     std::vector<double> GetColumnByName (const std::string& name) const;
     std::vector<std::string> GetGroups() const;
-    Rcpp::DataFrame GetCountTable() const {return countTable;}
     Rcpp::DataFrame ReCreateDataFrame() const;
 private:
     void CreateNameToIndex();
-    struct IndexAbundancePair {
-        int groupIndex;
-        int sequenceIndex;
-        double abundance;
-    };
     std::unordered_map<std::string, size_t> nameToRowIndex;
-    std::vector<std::string> sampleNames;
+    std::vector<std::string> sequenceNames;
     std::unordered_map<std::string, std::vector<double>> dataFrameMap;
     std::vector<std::string> groups;
-    Rcpp::DataFrame countTable{};
 };
 
 
