@@ -7,9 +7,14 @@
 bool ColumnReaderTestFixture::TestReadColumnFile(const std::string &file, const Rcpp::DataFrame& df,
                                                  const int expectedResult) {
     Setup();
-    reader->CreateCountTableAdapter(df);
+    CountTableAdapter countTable;
+    countTable.CreateDataFrameMap(df);
+    reader = new ColumnDistanceMatrixReader(0.2, false);
+    reader->SetCountTableAdapter(countTable);
     reader->Read(file);
-    const int result = reader->GetListVector()->getNumSeqs();
+    const ListVector* listVector = reader->GetListVector();
+    const int result = listVector->getNumSeqs();
+    delete listVector;
     TearDown();
     return result == expectedResult;
 }
@@ -17,9 +22,14 @@ bool ColumnReaderTestFixture::TestReadColumnFile(const std::string &file, const
 bool ColumnReaderTestFixture::TestGetDistanceMatrix(const std::string& filePath,
     const Rcpp::DataFrame& df, const bool expectedResult) {
     Setup();
-    reader->CreateCountTableAdapter(df);
+    CountTableAdapter countTable;
+    countTable.CreateDataFrameMap(df);
+    reader = new ColumnDistanceMatrixReader(0.2, false);
+    reader->SetCountTableAdapter(countTable);
     reader->Read(filePath);
-    const auto result = !reader->GetSparseMatrix()->seqVec.empty();
+    const SparseDistanceMatrix* sparseMatrix = reader->GetSparseMatrix();
+    const auto result = !sparseMatrix->seqVec.empty();
+    delete sparseMatrix;
     TearDown();
     return result == expectedResult;
 }
@@ -27,15 +37,20 @@ bool ColumnReaderTestFixture::TestGetDistanceMatrix(const std::string& filePath,
 bool ColumnReaderTestFixture::TestGetListVector(const std::string& filePath,
     const Rcpp::DataFrame& df, const int expectedResult) {
     Setup();
-    reader->CreateCountTableAdapter(df);
+    CountTableAdapter countTable;
+    countTable.CreateDataFrameMap(df);
+    reader = new ColumnDistanceMatrixReader(0.2, false);
+    reader->SetCountTableAdapter(countTable);
     reader->Read(filePath);
-    const auto result = reader->GetListVector()->getNumSeqs();
+    const ListVector* listVector = reader->GetListVector();
+    const auto result = listVector->getNumSeqs();
+    delete listVector;
     TearDown();
     return result == expectedResult;
 }
 
 void ColumnReaderTestFixture::Setup() {
-    reader = new ColumnDistanceMatrixReader(0.2, false);
+    //
 }
 
 void ColumnReaderTestFixture::TearDown() {
