@@ -7,7 +7,10 @@
 bool PhylipReaderTestFixture::TestReadPhylipFile(const Rcpp::DataFrame& df,
     const std::string &file, const bool expectedResult) {
     Setup();
-    reader->CreateCountTableAdapter(df);
+    CountTableAdapter countTable;
+    countTable.CreateDataFrameMap(df);
+    reader = new ReadPhylipMatrix(0.2, false);
+    reader->SetCountTableAdapter(countTable);
     const bool result = reader->Read(file);
     TearDown();
     return result == expectedResult;
@@ -17,9 +20,14 @@ bool PhylipReaderTestFixture::TestReadPhylipFile(const Rcpp::DataFrame& df,
 bool PhylipReaderTestFixture::TestGetSparseMatrix(const Rcpp::DataFrame& df,
     const std::string &file, const bool expectedResult) {
     Setup();
-    reader->CreateCountTableAdapter(df);
+    CountTableAdapter countTable;
+    countTable.CreateDataFrameMap(df);
+    reader = new ReadPhylipMatrix(0.2, false);
+    reader->SetCountTableAdapter(countTable);
     reader->Read(file);
-    const auto result = !reader->GetSparseMatrix()->seqVec.empty();
+    const SparseDistanceMatrix* sparseMatrix = reader->GetSparseMatrix();
+    const auto result = !sparseMatrix->seqVec.empty();
+    delete sparseMatrix;
     TearDown();
     return result == expectedResult;
 
@@ -28,16 +36,21 @@ bool PhylipReaderTestFixture::TestGetSparseMatrix(const Rcpp::DataFrame& df,
 bool PhylipReaderTestFixture::TestGetListVector(const Rcpp::DataFrame& df,
     const std::string &file, const int expectedResult) {
     Setup();
-    reader->CreateCountTableAdapter(df);
+    CountTableAdapter countTable;
+    countTable.CreateDataFrameMap(df);
+    reader = new ReadPhylipMatrix(0.2, false);
+    reader->SetCountTableAdapter(countTable);
     reader->Read(file);
-    const int result = reader->GetListVector()->getNumSeqs();
+    const ListVector* listVector = reader->GetListVector();
+    const int result = listVector->getNumSeqs();
+    delete listVector;
     TearDown();
     return result == expectedResult;
 }
 
 
 void PhylipReaderTestFixture::Setup() {
-    reader = new ReadPhylipMatrix(0.2, false);
+    // Do nothing
 }
 
 void PhylipReaderTestFixture::TearDown() {
