@@ -7,8 +7,8 @@
 bool SharedFileTestFixture::TestSharedFilePrintData(const std::vector<SharedAbundance> &data,
                                                     const Rcpp::DataFrame &expectedResult) {
     Setup();
-    sharedFile = new SharedFile(data);
-    Rcpp::DataFrame df = sharedFile->PrintData("otu");
+    SharedFile sharedFile(data);
+    Rcpp::DataFrame df = sharedFile.PrintData("otu");
     const std::vector<std::string> columnNames = df.names();
     const std::vector<std::string> expectedNames = expectedResult.names();
     TearDown();
@@ -16,9 +16,9 @@ bool SharedFileTestFixture::TestSharedFilePrintData(const std::vector<SharedAbun
 }
 
 void SharedFileTestFixture::Setup() {
-    sharedFile = nullptr;
+
 }
 
 void SharedFileTestFixture::TearDown() {
-    delete(sharedFile);
+
 }
