@@ -12,14 +12,13 @@
 
 class MatrixAdapterTestFixture final: public TestFixture {
 public:
-    bool TestCreateSparseMatrix(size_t expectedResult);
-    bool TestGetListVector(bool createSparseFirst, bool expectedResult);
+    bool TestCreateSparseMatrix(const MatrixAdapter& adapter, size_t expectedResult);
+    bool TestGetListVector(const MatrixAdapter& adapter, bool expectedResult);
     ~MatrixAdapterTestFixture() override;
 private:
 
     void Setup() override;
     void TearDown() override;
-    MatrixAdapter* matrixAdapter = nullptr;
 };
 
 
